@@ -91,9 +91,12 @@ class _Psycopg2Adapter(_PsycopgAdapter):
     # not defined in psycopg2.extensions
     # "select typname from pg_type where oid=705";
     UNKNOWN = 705
+    returns_unicode = True
 
     def __init__(self, native_module, pywrap=False):
         from psycopg2 import extensions
+        extensions.register_type(extensions.UNICODE)
+        extensions.register_type(extensions.UNICODEARRAY)
         self.BOOLEAN = extensions.BOOLEAN
         db.DBAPIAdapter.__init__(self, native_module, pywrap)
         self._init_psycopg2()
@@ -298,13 +301,7 @@ class _PGAdvFuncHelper(db._GenericAdvFuncHelper):
 
     def has_fti_table(self, cursor):
         if super(_PGAdvFuncHelper, self).has_fti_table(cursor):
-            cursor.execute('SELECT version()')
-            version = cursor.fetchone()[0].split()[1].split(',')[0]
-            version = [int(i) for i in version.split('.')]
-            if version >= [8, 3, 0]:
-                self.config = 'simple'
-            else:
-                self.config = 'default'
+            self.config = 'simple'
         return self.fti_table in self.list_tables(cursor)
 
     def cursor_index_object(self, uid, obj, cursor):
